==> zio-aws-mediatailor_3-5.17.103.1-sources.jar: zio/aws/mediatailor/model/ListAlertsResponse.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListAlertsResponse(
    items: Option[Iterable[zio.aws.mediatailor.model.Alert]] = None,
    nextToken: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.ListAlertsResponse = {
    import ListAlertsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.ListAlertsResponse
      .builder()
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .optionallyWith(
        nextToken.map(value => __string.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.ListAlertsResponse.ReadOnly =
    zio.aws.mediatailor.model.ListAlertsResponse.wrap(buildAwsValue())
}
object ListAlertsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.ListAlertsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.ListAlertsResponse =
      zio.aws.mediatailor.model.ListAlertsResponse(
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def items: Option[List[zio.aws.mediatailor.model.Alert.ReadOnly]]
    def nextToken: Option[__string]
    def getItems
        : ZIO[Any, AwsError, List[zio.aws.mediatailor.model.Alert.ReadOnly]] =
      AwsError.unwrapOptionField("items", items)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.ListAlertsResponse
  ) extends zio.aws.mediatailor.model.ListAlertsResponse.ReadOnly {
    override val items: Option[List[zio.aws.mediatailor.model.Alert.ReadOnly]] =
      scala
        .Option(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.mediatailor.model.Alert.wrap(item)
          }.toList
        )
    override val nextToken: Option[__string] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.mediatailor.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.ListAlertsResponse
  ): zio.aws.mediatailor.model.ListAlertsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.17.158.3-sources.jar: zio/aws/mediatailor/model/ListAlertsResponse.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListAlertsResponse(
    items: Option[Iterable[zio.aws.mediatailor.model.Alert]] = None,
    nextToken: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.ListAlertsResponse = {
    import ListAlertsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.ListAlertsResponse
      .builder()
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.ListAlertsResponse.ReadOnly =
    zio.aws.mediatailor.model.ListAlertsResponse.wrap(buildAwsValue())
}
object ListAlertsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.ListAlertsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.ListAlertsResponse =
      zio.aws.mediatailor.model.ListAlertsResponse(
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def items: Option[List[zio.aws.mediatailor.model.Alert.ReadOnly]]
    def nextToken: Option[__string]
    def getItems
        : ZIO[Any, AwsError, List[zio.aws.mediatailor.model.Alert.ReadOnly]] =
      AwsError.unwrapOptionField("items", items)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.ListAlertsResponse
  ) extends zio.aws.mediatailor.model.ListAlertsResponse.ReadOnly {
    override val items: Option[List[zio.aws.mediatailor.model.Alert.ReadOnly]] =
      scala
        .Option(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.mediatailor.model.Alert.wrap(item)
          }.toList
        )
    override val nextToken: Option[__string] =
      scala.Option(impl.nextToken()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.ListAlertsResponse
  ): zio.aws.mediatailor.model.ListAlertsResponse.ReadOnly = new Wrapper(impl)
}
